@@ -51,8 +51,10 @@ in this Software without prior written authorization from the XFree86 Project.
 /* for visuals */
 #include "fb.h"
 
-#include "xf86Resources.h"
-#include "xf86RAC.h"
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 6
+# include "xf86Resources.h"
+# include "xf86RAC.h"
+#endif
 
 #ifdef XvExtension
 # include "xf86xv.h"
@@ -112,12 +114,12 @@ static int pix24bpp = 0;
 #define IVTVDEV_DRIVER_NAME	"ivtv"
 #define IVTVDEV_VERSION_MAJOR	1
 #define IVTVDEV_VERSION_MINOR	1
-#define IVTVDEV_VERSION_PATCH	0
+#define IVTVDEV_VERSION_PATCH	1
 #define IVTVDEV_VERSION	((IVTVDEV_VERSION_MAJOR << 16) | \
 			(IVTVDEV_VERSION_MINOR << 8) | \
 			(IVTVDEV_VERSION_PATCH))
 
-DriverRec IVTVDEV = {
+_X_EXPORT DriverRec IVTVDEV = {
     IVTVDEV_VERSION,
     IVTVDEV_DRIVER_NAME,
     IVTVDevIdentify,
@@ -175,7 +177,7 @@ static XF86ModuleVersionInfo IVTVDevVersRec = {
     {0, 0, 0, 0}
 };
 
-XF86ModuleData ivtvModuleData = { &IVTVDevVersRec, IVTVDevSetup, NULL };
+_X_EXPORT XF86ModuleData ivtvModuleData = { &IVTVDevVersRec, IVTVDevSetup, NULL };
 
 pointer
 IVTVDevSetup(pointer module, pointer opts, int *errmaj, int *errmin)
@@ -185,7 +187,9 @@ IVTVDevSetup(pointer module, pointer opts, int *errmaj, int *errmin)
     if (!setupDone) {
 	setupDone = TRUE;
 	xf86AddDriver(&IVTVDEV, module, 0);
+#ifndef HAVE_XEXTPROTO_71
 	LoaderRefSymLists(fbSymbols, shadowSymbols, NULL);
+#endif
 	return (pointer) 1;
     }
     if (errmaj)
@@ -403,6 +407,7 @@ IVTVDevPreInit(ScrnInfoPtr pScrn, int flags)
 
     devPtr->pEnt = xf86GetEntityInfo(pScrn->entityList[0]);
 
+#ifndef XSERVER_LIBPCIACCESS
     pScrn->racMemFlags = RAC_FB | RAC_COLORMAP | RAC_CURSOR | RAC_VIEWPORT;
     /* XXX Is this right?  Can probably remove RAC_FB */
     pScrn->racIoFlags = RAC_FB | RAC_COLORMAP | RAC_CURSOR | RAC_VIEWPORT;
@@ -413,6 +418,7 @@ IVTVDevPreInit(ScrnInfoPtr pScrn, int flags)
 	    "DevPreInit: xf86RegisterResources() found resource conflicts\n");
 	return FALSE;
     }
+#endif
 
     /* open device */
     if (!ivtvHWInit(pScrn, NULL,
@@ -519,9 +525,12 @@ IVTVDevPreInit(ScrnInfoPtr pScrn, int flags)
 	IVTVDevFreeRec(pScrn);
 	return FALSE;
     }
+
+#ifndef HAVE_XEXTPROTO_71
     if (mod && syms) {
 	xf86LoaderReqSymLists(syms, NULL);
     }
+#endif
 
     /* Load shadow */
     xf86DrvMsg(pScrn->scrnIndex, X_CONFIG, "Using \"Shadow Framebuffer\"\n");
@@ -529,7 +538,10 @@ IVTVDevPreInit(ScrnInfoPtr pScrn, int flags)
 	IVTVDevFreeRec(pScrn);
 	return FALSE;
     }
+
+#ifndef HAVE_XEXTPROTO_71
     xf86LoaderReqSymLists(shadowSymbols, NULL);
+#endif
 
     TRACE_EXIT("PreInit");
     return TRUE;
